##  Introduction
Users are allowed to select from a range of distinct views when generating a report. Views are essentially attributes or relations, which are represented through a color-coded visualization. Each view provides a unique perspective on the data, enabling the user to gain better insights. Report views are selected from the View dropdown box on the report and can be based on the following:
  * Fields on fact sheets: Attributes on the base fact sheet type of the Report. In some cases, this attribute may be derived or calculated, e.g., Aggregated Obsolescence Risk.
  * Fields on Relations: Attributes that you find in a relation between the base fact sheet type and a related fact sheet, e.g., the Total annual cost attribute is stored in the relation between an Application and an IT Component.
  * Fields on Related Fact Sheets: Attributes from fact sheets not shown in the report but related to the fact sheets displayed, e.g., the functional fit of an Application in an IT Component Landscape Report.
  * Tags: User-defined tags. You can change the colors associated with tags. For more information, see [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction").


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275317917a44101482939e732c172b77_LowRes.png)
